==> beans-ddi-lifecycle-1.0.0-20130315.185109-6-sources.jar: org/openmetadata/beans/ddi/lifecycle/physicalinstance/impl/VariableStatisticsBeanImpl.java <==
package org.openmetadata.beans.ddi.lifecycle.physicalinstance.impl;

import org.openmetadata.beans.ddi.lifecycle.adt.impl.DdiBeanListImpl;
import org.openmetadata.beans.ddi.lifecycle.factory.DdiBeanFactory;
import org.openmetadata.beans.ddi.lifecycle.logicalproduct.VariableBean;
import org.openmetadata.beans.ddi.lifecycle.physicalinstance.CategoryStatisticsBean;
import org.openmetadata.beans.ddi.lifecycle.physicalinstance.SummaryStatisticBean;
import org.openmetadata.beans.ddi.lifecycle.physicalinstance.VariableStatisticsBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.impl.ReferenceBeanImpl;
import org.openmetadata.beans.ddi.lifecycle.reusable.impl.UnsettableDdiBeanImpl;
import org.openmetadata.beans.ddi.lifecycle.utility.CompareUtil;
import org.openmetadata.beans.exceptions.ResolverException;
import org.openmetadata.beans.impl.MutableBeanInitializer;
import org.openmetadata.beans.notification.ChangeListener;

public class VariableStatisticsBeanImpl extends UnsettableDdiBeanImpl implements
		VariableStatisticsBean {

	private ReferenceBeanImpl<VariableBean> variableReference;
	private Integer totalResponses;
	private DdiBeanListImpl<SummaryStatisticBean> summaryStatList;
	private DdiBeanListImpl<CategoryStatisticsBean> categoryStatsList;

	public VariableStatisticsBeanImpl(
			final MutableBeanInitializer beanInitializer,
			DdiBeanFactory factory,
			ChangeListener listener) {
		super(factory, listener);

		variableReference = new ReferenceBeanImpl<VariableBean>(
				VariableBean.class, factory, this);
		totalResponses = null;

		summaryStatList = new DdiBeanListImpl<SummaryStatisticBean>(
				SummaryStatisticBean.class, beanInitializer, factory, this) {
			@Override
			protected SummaryStatisticBean createNew() {
				return new SummaryStatisticBeanImpl(
						VariableStatisticsBeanImpl.this.getBeanFactory(),
						VariableStatisticsBeanImpl.this);
			}
		};
		categoryStatsList = new DdiBeanListImpl<CategoryStatisticsBean>(
				CategoryStatisticsBean.class, beanInitializer, factory, this) {
			@Override
			protected CategoryStatisticsBean createNew() {
				return new CategoryStatisticsBeanImpl(
						beanInitializer,
						VariableStatisticsBeanImpl.this.getBeanFactory(),
						VariableStatisticsBeanImpl.this);
			}
		};
	}

	@Override
	public String getVariableUrn() {
		return variableReference.getUrn();
	}

	public ReferenceBeanImpl<VariableBean> getVariableReference() {
		return variableReference;
	}

	@Override
	public void setVariableBean(VariableBean variable)
			 {
		variableReference.setReferenceTo(variable);
	}

	@Override
	public VariableBean getVariable() {
		try {
			return variableReference.getReferredObject();
		} catch (ResolverException e) {
			return null;
		}
	}

	@Override
	public boolean isSetTotalResponses() {
		return this.totalResponses != null;
	}

	@Override
	public int getTotalResponses() {
		if (this.totalResponses != null) {
			return this.totalResponses;
		} else {
			return 0;
		}
	}

	@Override
	public void setTotalResponses(int value) {
		if (CompareUtil.areDifferentValues(this.totalResponses, value)) {
			this.totalResponses = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public DdiBeanListImpl<SummaryStatisticBean> getSummaryStatisticList() {
		return this.summaryStatList;
	}

	@Override
	public DdiBeanListImpl<CategoryStatisticsBean> getCategoryStatisticsList() {
		return this.categoryStatsList;
	}
	
	@Override
	protected boolean internalIsSet() {
		return variableReference.isSet();
	}
}

==> beans-ddi-lifecycle-1.0.0-20130708.211540-17-sources.jar: org/openmetadata/beans/ddi/lifecycle/physicalinstance/impl/VariableStatisticsBeanImpl.java <==
package org.openmetadata.beans.ddi.lifecycle.physicalinstance.impl;

import org.openmetadata.beans.ddi.lifecycle.adt.impl.DdiBeanListImpl;
import org.openmetadata.beans.ddi.lifecycle.factory.DdiBeanFactory;
import org.openmetadata.beans.ddi.lifecycle.logicalproduct.VariableBean;
import org.openmetadata.beans.ddi.lifecycle.physicalinstance.CategoryStatisticsBean;
import org.openmetadata.beans.ddi.lifecycle.physicalinstance.SummaryStatisticBean;
import org.openmetadata.beans.ddi.lifecycle.physicalinstance.VariableStatisticsBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.impl.ReferenceBeanImpl;
import org.openmetadata.beans.ddi.lifecycle.reusable.impl.UnsettableDdiBeanImpl;
import org.openmetadata.beans.ddi.lifecycle.utility.CompareUtil;
import org.openmetadata.beans.exceptions.ResolverException;
import org.openmetadata.beans.impl.MutableBeanInitializer;
import org.openmetadata.beans.notification.ChangeListener;

public class VariableStatisticsBeanImpl extends UnsettableDdiBeanImpl implements
		VariableStatisticsBean {

	private ReferenceBeanImpl<VariableBean> variableReference;
	private Integer totalResponses;
	private DdiBeanListImpl<SummaryStatisticBean> summaryStatList;
	private DdiBeanListImpl<CategoryStatisticsBean> categoryStatsList;

	public VariableStatisticsBeanImpl(
			final MutableBeanInitializer beanInitializer,
			DdiBeanFactory factory,
			ChangeListener listener) {
		super(factory, listener);

		variableReference = new ReferenceBeanImpl<VariableBean>(
				VariableBean.class, factory, this);
		totalResponses = null;

		summaryStatList = new DdiBeanListImpl<SummaryStatisticBean>(
				SummaryStatisticBean.class, beanInitializer, factory, this) {
			@Override
			protected SummaryStatisticBean createNew() {
				return new SummaryStatisticBeanImpl(
						VariableStatisticsBeanImpl.this.getBeanFactory(),
						VariableStatisticsBeanImpl.this);
			}
		};
		categoryStatsList = new DdiBeanListImpl<CategoryStatisticsBean>(
				CategoryStatisticsBean.class, beanInitializer, factory, this) {
			@Override
			protected CategoryStatisticsBean createNew() {
				return new CategoryStatisticsBeanImpl(
						beanInitializer,
						VariableStatisticsBeanImpl.this.getBeanFactory(),
						VariableStatisticsBeanImpl.this);
			}
		};
	}
	
	public void initSetVariable(String variableUrn) {
		this.variableReference.setReferenceUrn(variableUrn);
	}

	@Override
	public String getVariableUrn() {
		return variableReference.getUrn();
	}

	public ReferenceBeanImpl<VariableBean> getVariableReference() {
		return variableReference;
	}

	@Override
	public void setVariableBean(VariableBean variable)
			 {
		variableReference.setReferenceTo(variable);
	}

	@Override
	public VariableBean getVariable() {
		try {
			return variableReference.getReferredObject();
		} catch (ResolverException e) {
			return null;
		}
	}

	@Override
	public boolean isSetTotalResponses() {
		return this.totalResponses != null;
	}

	@Override
	public int getTotalResponses() {
		if (this.totalResponses != null) {
			return this.totalResponses;
		} else {
			return 0;
		}
	}

	@Override
	public void setTotalResponses(int value) {
		if (CompareUtil.areDifferentValues(this.totalResponses, value)) {
			this.totalResponses = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public DdiBeanListImpl<SummaryStatisticBean> getSummaryStatisticList() {
		return this.summaryStatList;
	}

	@Override
	public DdiBeanListImpl<CategoryStatisticsBean> getCategoryStatisticsList() {
		return this.categoryStatsList;
	}
	
	@Override
	protected boolean internalIsSet() {
		return variableReference.isSet();
	}
}
